@@ -21,7 +21,7 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::XMP;
 use Image::ExifTool::GPS;
 
-$VERSION = '1.07';
+$VERSION = '1.09';
 
 sub ExtractObject($$;$);
 sub Get24u($$);
@@ -37,6 +37,11 @@ my %readProc = (
     0x108 => \&GetDouble,
 );
 
+# recognize different types of PLIST files based on certain tags
+my %plistType = (
+    adjustmentBaseVersion => 'AAE',
+);
+
 # PLIST tags (generated on-the-fly for most tags)
 %Image::ExifTool::PLIST::Main = (
     PROCESS_PROC => \&ProcessPLIST,
@@ -173,6 +178,8 @@ sub FoundTag($$$$;$)
         delete $$et{LIST_TAGS}{$$et{LastPListTag}};
     }
     $$et{LastPListTag} = $tagInfo;
+    # override file type if applicable
+    $et->OverrideFileType($plistType{$tag}) if $plistType{$tag} and $$et{FILE_TYPE} eq 'XMP';
     # save the tag
     $et->HandleTag($tagTablePtr, $tag, $val);
 
@@ -323,12 +330,12 @@ sub ProcessBinaryPLIST($$$)
 {
     my ($et, $dirInfo, $tagTablePtr) = @_;
     my ($i, $buff, @table);
+    my $dataPt = $$dirInfo{DataPt};
 
     $et->VerboseDir('Binary PLIST');
     SetByteOrder('MM');
 
-    unless ($$dirInfo{RAF}) {
-        my $dataPt = $$dirInfo{DataPt};
+    if ($dataPt) {
         my $start = $$dirInfo{DirStart};
         if ($start or ($$dirInfo{DirLen} and $$dirInfo{DirLen} != length $$dataPt)) {
             my $buf2 = substr($$dataPt, $start || 0, $$dirInfo{DirLen});
@@ -339,7 +346,7 @@ sub ProcessBinaryPLIST($$$)
         my $strt = $$dirInfo{DirStart} || 0;
     }
     # read and parse the trailer
-    my $raf = $$dirInfo{RAF};
+    my $raf = $$dirInfo{RAF} or return 0;
     $raf->Seek(-32,2) and $raf->Read($buff,32)==32 or return 0;
     my $intSize = Get8u(\$buff, 6);
     my $refSize = Get8u(\$buff, 7);
