@@ -290,7 +290,7 @@ sub WriteNewTags($$$)
         my $tagInfo = $$newTags{$tag};
         my $nvHash = $et->GetNewValueHash($tagInfo);
         next unless $$nvHash{IsCreating};
-        my $val = $et->GetNewValues($nvHash);
+        my $val = $et->GetNewValue($nvHash);
         $et->VerboseValue("+ PostScript:$$tagInfo{Name}", $val);
         Write($outfile, EncodeTag($tag, $val)) or $success = 0;
         ++$$et{CHANGED};
@@ -583,7 +583,7 @@ sub WritePS($$)
                 my $nvHash = $et->GetNewValueHash($tagInfo);
                 if ($et->IsOverwriting($nvHash, $val)) {
                     $et->VerboseValue("- PostScript:$$tagInfo{Name}", $val);
-                    $val = $et->GetNewValues($nvHash);
+                    $val = $et->GetNewValue($nvHash);
                     ++$$et{CHANGED};
                     next unless defined $val;   # next if tag is being deleted
                     $et->VerboseValue("+ PostScript:$$tagInfo{Name}", $val);
@@ -759,7 +759,7 @@ Thanks to Tim Kordick for his help testing the EPS writer.
 
 =head1 AUTHOR
 
-Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
